.aaf.integer: Generic constructor for classes extending integer
Description
Retrieve annotation from an integer data source.
Usage
.aaf.integer(probeids, chip, type, class)
Arguments
probeids
character vector containing probe ids
class
class of object to be created
Value
A list of objects of class class containing the annotation
data of from the type dataset for the given probeids.
NA values are returned as empty objects.